==> monodevelop-database_2.0+dfsg.orig.tar.gz: monodevelop-database-2.0/MonoDevelop.Database.Sql/Schema/DatabaseSchema.cs <==
//
// Authors:
//	Ben Motmans  <ben.motmans@gmail.com>
//
// Copyright (c) 2007 Ben Motmans
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;

namespace MonoDevelop.Database.Sql
{
	/// <summary>
	/// SQL schema object representing a database
	/// </summary>
	public class DatabaseSchema : AbstractSchema
	{
		public DatabaseSchema (ISchemaProvider schemaProvider)
			: base (schemaProvider)
		{
		}
		
		public DatabaseSchema (DatabaseSchema schema)
			: base (schema)
		{
		}
		
		public override object Clone ()
		{
			return new DatabaseSchema (this);
		}
	}
}

==> monodevelop-database_2.8.6.3+dfsg.orig.tar.gz: monodevelop-database-2.8.6.3/MonoDevelop.Database.Sql/Schema/DatabaseSchema.cs <==
//
// Authors:
//	Ben Motmans  <ben.motmans@gmail.com>
//
// Copyright (c) 2007 Ben Motmans
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;

namespace MonoDevelop.Database.Sql
{
	/// <summary>
	/// SQL schema object representing a database
	/// </summary>
	public class DatabaseSchema : AbstractSchema
	{
		public System.Collections.Generic.List<LineStatement> AfterCreationStatements = new 
			System.Collections.Generic.List<LineStatement>();
		
		
		public DatabaseSchema (ISchemaProvider schemaProvider)
			: base (schemaProvider)
		{
			
		}
		
		public DatabaseSchema (DatabaseSchema schema)
			: base (schema)
		{
		}
		
		public override object Clone ()
		{
			return new DatabaseSchema (this);
		}
		
	}
}
